pub struct EntityAttribute {
pub logical_name: String,
pub schema_name: String,
pub attribute_type: Option<String>,
pub attribute_type_name: Option<AttributeTypeName>,
pub is_custom_attribute: Option<bool>,
pub is_valid_odata_attribute: Option<bool>,
pub is_valid_for_read: Option<bool>,
pub is_valid_for_update: Option<bool>,
}Expand description
Dataverse attribute metadata.
Fields
logical_name: StringLogical name of the attribute.
schema_name: StringSchema name of the attribute.
attribute_type: Option<String>Attribute type name.
attribute_type_name: Option<AttributeTypeName>Specific attribute type name.
is_custom_attribute: Option<bool>True if the attribute is custom.
is_valid_odata_attribute: Option<bool>True if the attribute is valid for OData.
is_valid_for_read: Option<bool>True if the attribute is valid for read operations.
is_valid_for_update: Option<bool>True if the attribute is valid for update operations.