pub struct RequestParameters {
pub bypass_business_logic_execution_custom_sync: bool,
pub bypass_business_logic_execution_custom_async: bool,
pub bypass_custom_plugin_execution: bool,
pub suppress_callback_registration_expander_job: bool,
}Expand description
Optional Dataverse request parameters for create and update operations.
Fields
bypass_business_logic_execution_custom_sync: boolSend MSCRM.BypassBusinessLogicExecution=CustomSync.
bypass_business_logic_execution_custom_async: boolSend MSCRM.BypassBusinessLogicExecution=CustomAsync.
bypass_custom_plugin_execution: boolSend MSCRM.BypassCustomPluginExecution=true.
suppress_callback_registration_expander_job: boolSend MSCRM.SuppressCallbackRegistrationExpanderJob=true.
Implementations
Sourceimpl RequestParameters
impl RequestParameters
Sourcepub fn headers(&self) -> Vec<(&'static str, &'static str)>
pub fn headers(&self) -> Vec<(&'static str, &'static str)>
Return the Dataverse request headers represented by these parameters.
Sourcepub fn apply(&self, request: RequestBuilder) -> RequestBuilder
pub fn apply(&self, request: RequestBuilder) -> RequestBuilder
Apply the configured Dataverse request parameters to an outgoing request.